import * as React from 'react';
import * as PropTypes from 'prop-types';
import { LineInformation } from './compute-lines';
import { ReactDiffViewerStylesOverride } from './styles';
export declare enum LineNumberPrefix {
    LEFT = "L",
    RIGHT = "R"
}
export interface ReactDiffViewerProps {
    oldValue: string;
    newValue: string;
    splitView?: boolean;
    disableWordDiff?: boolean;
    extraLinesSurroundingDiff?: number;
    hideLineNumbers?: boolean;
    showDiffOnly?: boolean;
    renderContent?: (source: string) => JSX.Element;
    codeFoldMessageRenderer?: (totalFoldedLines: number, leftStartLineNumber: number, rightStartLineNumber: number) => JSX.Element;
    onLineNumberClick?: (lineId: string, event: React.MouseEvent<HTMLTableCellElement>) => void;
    highlightLines?: string[];
    styles?: ReactDiffViewerStylesOverride;
}
export interface ReactDiffViewerState {
    expandedBlocks?: number[];
}
declare class DiffViewer extends React.Component<ReactDiffViewerProps, ReactDiffViewerState> {
    private styles;
    static defaultProps: ReactDiffViewerProps;
    static propTypes: {
        oldValue: PropTypes.Validator<string>;
        newValue: PropTypes.Validator<string>;
        splitView: PropTypes.Requireable<boolean>;
        disableWordDiff: PropTypes.Requireable<boolean>;
        renderContent: PropTypes.Requireable<(...args: any[]) => any>;
        onLineNumberClick: PropTypes.Requireable<(...args: any[]) => any>;
        extraLinesSurroundingDiff: PropTypes.Requireable<number>;
        styles: PropTypes.Requireable<object>;
        hideLineNumbers: PropTypes.Requireable<boolean>;
        showDiffOnly: PropTypes.Requireable<boolean>;
        highlightLines: PropTypes.Requireable<string[]>;
    };
    constructor(props: ReactDiffViewerProps);
    private onBlockExpand;
    private computeStyles;
    private onLineNumberClickProxy;
    private renderWordDiff;
    private renderLine;
    private renderSplitView;
    renderInlineView: ({ left, right }: LineInformation, index: number) => JSX.Element;
    private onBlockClickProxy;
    private renderSkippedLineIndicator;
    render: () => JSX.Element;
}
export default DiffViewer;
export { ReactDiffViewerStylesOverride };
